import os
from unittest.mock import Mock

from OSM_outils.OMSnx_enregistrement import OMSnx_enregistrement
from django.conf import settings
from django.http import QueryDict
from django.test import TestCase
from recuperateur_reseau_viaire.forms import Graph_viaire_ville_informationForm

class form_creation_Graph_viaire_ville_informationTestCase(TestCase):

    def test_creation_form_vide(self):
        """
        Ce teste créé un formulaire de création de Graph_viaire_ville_information vide et ne doit pas être valide
        """
        form = Graph_viaire_ville_informationForm()
        self.assertFalse(form.is_valid())

    def test_creation_form_une_ville_non_existante(self):
        """
        Ce test créé un formulaire de création de Graph_viaire_ville_information avec un nom de ville qui n'existe pas
        """
        entree_form = QueryDict('gvvi_nom=coooooommmmmmuuuuuunnnnnneeeeee')
        form = Graph_viaire_ville_informationForm(entree_form)
        OMSnx_enregistrement.recuperer_graphe_viaire_ville = Mock()
        OMSnx_enregistrement.recuperer_graphe_viaire_ville.side_effect = ValueError("erreur : \"" + entree_form.get("gvvi_nom") + "\"")
        self.assertFalse(form.is_valid())
        self.assertTrue("ville non trouvée : " + entree_form.get("gvvi_nom") in form.errors["gvvi_nom"])

    def test_creation_form_une_ville_basic_fichier_existe_deja(self):
        """
        Ce test va voir si une ville avec un nom connu fonctionne. Ici, c'est le nom d'un fichier dans le dossier Data.
        """
        nom_ville = "Saint-Laurent-sur-Saône"
        entree_form = QueryDict('gvvi_nom='+nom_ville)
        form = Graph_viaire_ville_informationForm(entree_form)
        self.assertTrue(form.is_valid())

    def test_creation_form_une_ville_basic(self):
        """
        Ce test va voir si une ville avec un nom connu fonctionne. Ici, c'est le nom d'un fichier dans le dossier Data.
        """
        nom_ville = "Fécamp"
        entree_form = QueryDict('gvvi_nom='+nom_ville)
        form = Graph_viaire_ville_informationForm(entree_form)
        OMSnx_enregistrement.recuperer_graphe_viaire_ville = Mock()
        OMSnx_enregistrement.recuperer_graphe_viaire_ville.return_value = OMSnx_enregistrement.lire_graphe("Saint-Laurent-sur-Saône")
        self.assertTrue(form.is_valid())

    def test_creation_form_plusieurs_villes_une_ville_n_existe_pas(self):
        """
        Ici, on test la création d'une ville composé de plusieurs communes dont l'une des communes n'existe pas.
        """
        nom_ville = "super ville"
        nom_ville_englobees = ["Bolbec", "coooooommmmmmuuuuuunnnnnneeeeee"]
        entree_form = QueryDict('gvvi_nom=' + nom_ville + '&gvvi_nom_ajout=[' + nom_ville_englobees[0] + ", " + nom_ville_englobees[1] + "]")
        form = Graph_viaire_ville_informationForm(entree_form)
        OMSnx_enregistrement.recuperer_graphe_viaire_ville = Mock()
        OMSnx_enregistrement.recuperer_graphe_viaire_ville.side_effect = ValueError("erreur : \"" + nom_ville_englobees[1] + "\"")
        form.is_valid()
        self.assertTrue("ville non trouvée : " + nom_ville_englobees[1] in form.errors["gvvi_nom"])